@@ -4,51 +4,48 @@ import json
 import os
 import shutil
 
-from ingestion.caris.util.tar import unpack
+from ingestion.shared_util.tar import unpack
 from ingestion.caris.util.metadata import extract_metadata
 from ingestion.caris.util.structural import extract_structural
 from ingestion.caris.util.cnv import extract_cnv
 from ingestion.caris.util.tsv import convert_tsv_to_rgel
 from ingestion.caris.util.vcf import extract_sv
-from ingestion.caris.util.ga4gh import create_yaml
+from ingestion.shared_util.ga4gh import create_yaml
 from logging import Logger
 
 CARIS_CASE_ID_LENGTH = len("TN22-000000")
 
 
-def process_caris_json(
-    infile: str, outpath: str, file_name: str, source_file_id: str, ingest_status: dict, log: Logger
-):
+def handle_tsv(file: str, file_list: list[str]) -> dict[str, str]:
+    multiple_tsv = len([file for file in file_list if file.endswith("tsv")]) > 1
 
+    if not multiple_tsv or "Transformed" in file:
+        return {
+            "tsv": file,
+        }
+    return {}
+
+
+def process_caris_json(infile: str, outpath: str, file_name: str, source_file_id: str, log: Logger):
     # Unpack tarball and go into the new directory
     unpack(infile, outpath)
     os.chdir(outpath)
-    # If we do this we need to make sure we communicate it well.
-    #  shutil.move(args.input, f'{outpath}/{os.path.basename(args.input)}')
+
     file_list = glob.glob("*")
-    files = {}
+    files: dict[str, str] = {}
 
-    files["bam"] = []
-    files["R1.fastq.gz"] = []
-    files["R2.fastq.gz"] = []
-
-    # if file_list has more than one file that starts with DNA_ or RNA_ then we need to throw an error
+    # if file_list has more than one file that starts with DNA_ then we need to throw an error
     if len([file for file in file_list if file.startswith("DNA_")]) > 1:
         raise Exception(f"More than one DNA file found in {file_name}\n")
-    if len([file for file in file_list if file.startswith("RNA_")]) > 1:
-        raise Exception(f"More than one RNA file found in {file_name}\n")
 
     for file in file_list:
-        extension = file.split(".")[1:]
-        if not isinstance(extension, str):
-            extension = ".".join(extension)
-        # We can have multiple bam files (RNA and DNA)
-        if extension == "bam" or "fastq" in extension:
-            files[extension].append(file)
-        elif file.lower().startswith("germline"):
+        extension = ".".join(file.split(".")[1:])
+        if file.lower().startswith("germline") or file.startswith("gDNA"):
             files["germline.vcf"] = file
         elif file.endswith("vcf") and "germline" not in file:
             files["somatic.vcf"] = file
+        elif file.endswith("tsv"):
+            files.update(handle_tsv(file, file_list))
         else:
             files[extension] = file
 
@@ -56,12 +53,10 @@ def process_caris_json(
 
     json_file = files["json"]
 
-    f = open(json_file, "rb")
-    all_data = json.load(f)
-    data = all_data
-    if "root" in all_data.keys():
-        data = all_data["root"]
-    f.close()
+    with open(json_file, "rb") as f:
+        data = json.load(f)
+    if "root" in data:
+        data = data["root"]
 
     somatic_filename = None
     germline_filename = None
@@ -74,7 +69,6 @@ def process_caris_json(
             with open(files["somatic.vcf"], "rb") as f_in:
                 with gzip.open(somatic_filename, "wb") as f_out:
                     shutil.copyfileobj(f_in, f_out)
-            ingest_status["run_instructions"]["som_vcf"] = True
         if "germline.vcf" in key:
             germline_filename = (
                 files["germline.vcf"].replace("Germline_", "").replace(".vcf", ".germline.vcf")
@@ -83,19 +77,24 @@ def process_caris_json(
             with open(files["germline.vcf"], "rb") as f_in:
                 with gzip.open(germline_filename, "wb") as f_out:
                     shutil.copyfileobj(f_in, f_out)
-            ingest_status["run_instructions"]["germ_vcf"] = True
-            germline_case_id = files["germline.vcf"].replace("Germline_", "")[
-                0:CARIS_CASE_ID_LENGTH
-            ]
-    if "tsv" in files.keys():
-        ingest_status["run_instructions"]["som_rna"] = True
+            # Liquid cases don't start with `Germline_` and follow a different pattern for germline
+            if "germline" in files["germline.vcf"].lower():
+                germline_case_id = files["germline.vcf"].replace("Germline_", "")[
+                    0:CARIS_CASE_ID_LENGTH
+                ]
 
     # Get patient
-    metadata = extract_metadata(data, file_name, files, source_file_id, ingest_status, log)
-    structural_results = extract_structural(file_name, data, ingest_status, log)
-    cnv_results = extract_cnv(file_name, data, ingest_status, log)
-    rgel_results = convert_tsv_to_rgel(file_name, files, ingest_status, log)
-    vcf_results = extract_sv(file_name, ingest_status)
+    metadata, is_test_cancelled_permit_vcf_skip = extract_metadata(
+        data, file_name, files, source_file_id, log
+    )
+    structural_results = extract_structural(file_name, data, log)
+    cnv_results = extract_cnv(file_name, data, log)
+    rgel_results = convert_tsv_to_rgel(file_name, files, log)
+
+    include_empty = metadata["ihcTests"] and is_test_cancelled_permit_vcf_skip
+    vcf_results = extract_sv(
+        file_name, bool(somatic_filename), bool(germline_filename), include_empty
+    )
 
     # We might not have any of these files but we need an empty json object here.
     file_genome_references = {}
@@ -115,7 +114,7 @@ def process_caris_json(
             seq_type = vcf.get("sequenceType")
             file_genome_references[f"{seq_type}_genome_reference"] = vcf["reference"]
 
-    create_yaml(metadata, file_name, ingest_status)
+    create_yaml(metadata, file_name)
 
     # Return VCF files for immediate processing, and JSON data for adding vendsig
     result = {}
@@ -124,5 +123,7 @@ def process_caris_json(
         result["somatic_vcf"] = f"{outpath}/{somatic_filename}"
     if germline_filename is not None:
         result["germline_vcf"] = f"{outpath}/{germline_filename}"
+    if not germline_filename and not somatic_filename and include_empty:
+        result["somatic_vcf"] = f"{outpath}/{file_name}.modified.somatic.vcf.gz"
 
     return (result, germline_case_id, file_genome_references, data)
