@@ -47,25 +47,15 @@ def get_ordering_md(pmi, npi) -> list:
     return ordering_md_info
 
 
-def get_non_human_content(nhc_dicts) -> list:
+def get_non_human_content(nhc_dicts: list[dict]) -> list:
     nhc_final = []
 
-    if isinstance(nhc_dicts, list):
-        for sub_dict in nhc_dicts:
-            nhc_final.append(
-                {
-                    "nhcOrganism": sub_dict.get("@organism", "unknown"),
-                    "nhcReadsPerMil": float(sub_dict.get("@reads-per-million", 0.0)),
-                    "nhcStatus": sub_dict.get("@status", "unknown"),
-                }
-            )
-
-    else:
+    for sub_dict in nhc_dicts:
         nhc_final.append(
             {
-                "nhcOrganism": nhc_dicts.get("@organism", "unknown"),
-                "nhcReadsPerMil": float(nhc_dicts.get("@reads-per-million", 0.0)),
-                "nhcStatus": nhc_dicts.get("@status", "unknown"),
+                "nhcOrganism": sub_dict.get("@organism", "unknown"),
+                "nhcReadsPerMil": float(sub_dict.get("@reads-per-million", 0.0)),
+                "nhcStatus": sub_dict.get("@status", "unknown"),
             }
         )
 
@@ -77,13 +67,59 @@ def get_plasma_tumor_fraction(genes) -> Optional[str]:
         "Elevated Tumor Fraction": "Elevated",
         "Elevated Tumor Fraction Not Detected": "Not Elevated",
         "Cannot Be Determined": "Undetermined",
+        # 12/5/2023: Foundation renamed `Tumor Fraction` to `ctDNA Tumor Fraction`
+        # They also changed the values from `Elevated` and `Not Elevated` to `High` and `Low`
+        # We need to support both the old and the new names to account for reingestions
+        "Low": "Not Elevated",
+        "High": "Elevated",
+        # 12/2/2024 Foundation changed "Elevated Tumor Fraction Not Detected" to "Not Detected"
+        "Not Detected": "Not Elevated",
     }
-    ptf_entry = [
-        entry for entry in genes.get("Gene", {}) if entry.get("Name", "") == "Tumor Fraction"
-    ]
+    ptf_entry_names = ["Tumor Fraction", "ctDNA Tumor Fraction"]
+    entries = genes.get("Gene", [])
+    ptf_entry = next((entry for entry in entries if entry.get("Name", "") in ptf_entry_names), None)
     if ptf_entry:
-        ptf_val = ptf_entry[0].get("Alterations", "").get("Alteration", "").get("Name", "")
-        return [value for (key, value) in ptf_dict.items() if key == ptf_val][0]
+        ptf_val = ptf_entry.get("Alterations", {}).get("Alteration", {}).get("Name", "")
+        if ptf_val in ["> 0%", ">0%"]:
+            return "Elevated"
+        try:
+            # See https://github.com/lifeomic/phc-ingestion/pull/129
+            float_val = float(ptf_val.strip("%"))
+            if float_val > 0:
+                return "Elevated"
+            elif float_val == 0:
+                return "Not Elevated"
+        except ValueError:
+            # If it's not a numeric value, look it up in the dictionary
+            return ptf_dict[ptf_val]
+    else:
+        return None
+
+
+def get_plasma_tumor_fraction_score_from_value(value: str) -> Optional[float]:
+    if value == "Units Not Reported":
+        return None
+
+    stripped_value = value.strip("%")
+    try:
+        return float(stripped_value)
+    except ValueError:
+        return None
+
+
+def get_hrd_status(genes) -> Optional[str]:
+    hrd_dict = {
+        "HRD Positive": "positive",
+        "HRD Not Detected": "negative",
+    }
+    hrd_entry = [
+        entry
+        for entry in genes.get("Gene", {})
+        if entry.get("Name", "") == "Homologous Recombination status"
+    ]
+    if hrd_entry:
+        hrd_val = hrd_entry[0].get("Alterations", "").get("Alteration", "").get("Name", "")
+        return [value for (key, value) in hrd_dict.items() if key == hrd_val][0]
     else:
         return None
 
@@ -106,14 +142,24 @@ def get_test_yml(
     biomarkers = variant_report.get("biomarkers", {})
     non_human_content = variant_report.get("non-human-content", {})
     report_properties = results_payload_dict.get("FinalReport", {}).get("reportProperties", {})
-    report_property = report_properties.get("reportProperty", [])
-    genes = results_payload_dict.get("FinalReport", {}).get("Genes", {})
+    properties = report_properties.get("reportProperty", [])
+    # `Genes` may exist as a key but have a value of None, so we need to ensure it defaults to an empty dict
+    genes = results_payload_dict.get("FinalReport", {}).get("Genes", {}) or {}
     plasma_tumor_fraction = get_plasma_tumor_fraction(genes)
-    properties = report_property if isinstance(report_property, list) else [report_property]
+    hrd_status = get_hrd_status(genes)
     gw_loh = next(
         (prop for prop in properties if prop.get("@key") == "LossOfHeterozygosityScore"),
         None,
     )
+    plasma_tumor_fraction_score_value = next(
+        (prop for prop in properties if prop.get("@key") == "ComprehensiveTumorFractionScore"),
+        {},
+    ).get("value")
+    plasma_tumor_fraction_score = None
+    if plasma_tumor_fraction_score_value:
+        plasma_tumor_fraction_score = get_plasma_tumor_fraction_score_from_value(
+            plasma_tumor_fraction_score_value
+        )
 
     os.makedirs(f"{local_output_dir}/{base_xml_name}", exist_ok=True)
 
@@ -128,15 +174,26 @@ def get_test_yml(
 
     ordering_md_info = get_ordering_md(pmi, npi)
 
-    # fallback on previous behavior for indexedDate if value is not found
-    indexedDate = get_date(pmi.get("CollDate")) or get_date(sample.get("ReceivedDate"))
-
     # store both values sperately
     receivedDate = get_date(sample.get("ReceivedDate"))
     collDate = get_date(pmi.get("CollDate"))
 
     # store date of published report
     reportDate = str(get_date(signatures.get("Signature").get("ServerTime")))[0:10]
+    indexedDate = reportDate
+
+    sample_id = (sample.get("SampleId") or "").strip()
+    block_id = (sample.get("BlockId") or "").strip()
+    if block_id == "N/A":
+        block_id = ""
+
+    specimen_ids = []
+    if sample_id:
+        specimen_ids.append(sample_id)
+    if block_id:
+        specimen_ids.append(block_id)
+
+    specimenType = sample.get("SpecFormat", "").strip()
 
     yaml_file = {
         "name": "Foundation Medicine",
@@ -164,6 +221,11 @@ def get_test_yml(
         "files": [],
     }
 
+    if specimen_ids:
+        yaml_file["specimenIds"] = specimen_ids
+    if specimenType:
+        yaml_file["specimenTypes"] = [specimenType]
+
     if write_to_manifest["cnv"]:
         yaml_file["files"].append(
             {
@@ -189,7 +251,7 @@ def get_test_yml(
             {
                 "type": "shortVariant",
                 "sequenceType": "somatic",
-                "fileName": f"{phc_output_dir}/{base_xml_name}/{base_xml_name}.nrm.vcf.gz",
+                "fileName": f"{phc_output_dir}/{base_xml_name}/{base_xml_name}.modified.nrm.filtered.vcf.gz",
                 "reference": genome_reference,
             }
         )
@@ -213,8 +275,7 @@ def get_test_yml(
     if gw_loh:
         values = {"loh-high": "high", "loh-low": "low"}
         alterations = []
-        gene = genes.get("Gene", [])
-        genes_list = gene if isinstance(gene, list) else [gene]
+        genes_list = genes.get("Gene", [])
         for gene in genes_list:
             alt = gene.get("Alterations", {}).get("Alteration", [])
             alterations.extend(alt) if isinstance(alt, list) else alterations.append(alt)
@@ -247,7 +308,7 @@ def get_test_yml(
 
     # adding non-human content fields
     if non_human_content != None:
-        yaml_file["nonHumanContent"] = get_non_human_content(non_human_content.get("non-human", ""))
+        yaml_file["nonHumanContent"] = get_non_human_content(non_human_content.get("non-human", []))
 
     if report_file:
         copyfile(report_file, f"{local_output_dir}/{base_xml_name}/{base_xml_name}.report.pdf")
@@ -257,5 +318,12 @@ def get_test_yml(
     # add plasma tumor fraction
     if plasma_tumor_fraction:
         yaml_file["plasmaTumorFraction"] = plasma_tumor_fraction
+    # A score of 0 is a valid score, so we need to check for None
+    if plasma_tumor_fraction_score != None:
+        yaml_file["plasmaTumorFractionScore"] = plasma_tumor_fraction_score
+
+    # add homologous recombination deficiency
+    if hrd_status:
+        yaml_file["hrdStatus"] = hrd_status
 
     return yaml_file
